from django.apps import AppConfig


class SahimDjangoCommonConfig(AppConfig):
    """App configuration for sahim-django-common utilities."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "sahim_django_common"
    verbose_name = "Sahim Django Common"
    label = "sahim_django_common"
